@@ -13,7 +13,7 @@ class _Config(DottedDict):
 
     def __init__(self, filepath: str) -> None:
         """Initialize config."""
-        self.filepath = filepath
+        self._filepath = filepath
         self.reload()
 
     def reload(self) -> None:
@@ -23,13 +23,13 @@ class _Config(DottedDict):
     def write(self, config_dict: Dict) -> None:
         """Write new config file from `config_dict`."""
         self._validate(config_dict)
-        with open(self.filepath, "w") as config_file:
+        with open(self._filepath, "w") as config_file:
             yaml.dump(config_dict, config_file, default_flow_style=False)
         self.reload()
 
     def _read(self) -> Dict:
         """Get YAML config as dict."""
-        with open(self.filepath) as config_file:
+        with open(self._filepath) as config_file:
             config = yaml.load(config_file, Loader=yaml.FullLoader)
             return self._validate(config)
 
